searchData={"items":[{"type":"module","title":"ReqAthena","doc":"`Req` plugin for [AWS Athena](https://docs.aws.amazon.com/athena/latest/APIReference/Welcome.html).\n\nReqAthena makes it easy to make Athena queries and save the results into S3 buckets.\n\nBy default, `ReqAthena` will query results and use the default output format,\nwhich is CSV. To change that, you can use the `:format` option documented bellow.","ref":"ReqAthena.html"},{"type":"function","title":"ReqAthena.attach/2","doc":"Attaches to Req request.","ref":"ReqAthena.html#attach/2"},{"type":"function","title":"Request Options - ReqAthena.attach/2","doc":"* `:access_key_id` - Required. The Access Key ID from AWS credentials.\n\n  * `:secret_access_key` - Required. The Secret Access Key from AWS credentials.\n\n  * `:token` - Optional. The Session Token from AWS credentials.\n\n  * `:region` - Required. The AWS region where AWS Athena is installed.\n\n  * `:database` - Required. The AWS Athena database name.\n\n  * `:output_location` - Optional. The S3 URL location to output AWS Athena query results.\n    Results will be saved as Parquet and loaded with Explorer only if this option is given.\n\n  * `:workgroup` - Conditional. The AWS Athena workgroup.\n\n  * `:cache_query` - Optional. Forces a non-cached result from AWS Athena.\n\n  * `:format` - Optional. The output format. Can be one of:\n\n      * `:none` (default) - return decoded API response from Athena.\n      \n      * `:csv` - return contents of the CSV file.\n      \n      * `:json` - return contents of the JSON file.\n      \n        Note: Req by default automatically decodes JSON response body ([`decode_body`](Req.Steps.decode_body1/) step)\n        and to prevent it from doing so, set `decode_body: false`.\n        \n      * `:explorer` - return contents in parquet format, lazy loaded into Explorer data frame.\n\n\n    There are some limitations when using the `:json` and `:explorer` format.\n    First, you need to install Explorer in order to use the `:explorer` format.\n    Second, when using these format, you always need to provide a different output location.\n    See the [`UNLOAD` command docs](https://docs.aws.amazon.com/athena/latest/ug/unload.html#unload-considerations-and-limitations)\n    for more details.\n\n  * `:output_compression` - Optional. Sets the Parquet compression format and level\n    for the output when using the Explorer output format. This can be a string, like `\"gzip\"`,\n    or a tuple with `{format, level}`, like: `{\"ZSTD\", 4}`. By default this is `nil`,\n    which means that for Parquet (the format that Explorer uses) this is going to be `\"gzip\"`.\n\n  * `:athena` - Required. The query to execute. It can be a plain SQL string or\n    a `{query, params}` tuple, where `query` can contain `?` placeholders and `params`\n    is a list of corresponding values.\n\n    There is a limitation of Athena that requires the `:output_location` to be present\n    for every query that outputs to a format other than \"CSV\". So we append \"results\"\n    to the `:output_location` to make the partition files be saved there.\n\nConditional fields must always be defined, and can be one of the fields or both.\n\nIf you want to set any of these options when attaching the plugin, pass them as the second argument.","ref":"ReqAthena.html#attach/2-request-options"},{"type":"function","title":"Examples - ReqAthena.attach/2","doc":"With plain query string:\n\n    iex> opts = [\n    ...>   access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n    ...>   secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n    ...>   region: System.fetch_env!(\"AWS_REGION\"),\n    ...>   database: \"default\",\n    ...>   output_location: System.fetch_env!(\"AWS_ATHENA_OUTPUT_LOCATION\")\n    ...> ]\n    iex> query = \"SELECT id, type, tags, members, timestamp, visible FROM planet WHERE id = 470454 and type = 'relation'\"\n    iex> req = Req.new() |> ReqAthena.attach(opts)\n    iex> Req.post!(req, athena: query, format: :json).body\n    %{\n      \"id\" => 470454,\n      \"members\" => [\n        %{\"ref\" => 670007839, \"role\" => \"\", \"type\" => \"node\"},\n        %{\"ref\" => 670007840, \"role\" => \"\", \"type\" => \"node\"}\n      ],\n      \"tags\" => %{\n        \"name\" => \"Mérignac A\",\n        \"network\" => \"NTF-5\",\n        \"ref\" => \"17229A\",\n        \"site\" => \"geodesic\",\n        \"source\" => \"©IGN 2010 dans le cadre de la cartographie réglementaire\",\n        \"type\" => \"site\",\n        \"url\" => \"http://geodesie.ign.fr/fiches/index.php?module=e&action=fichepdf&source=carte&sit_no=17229A\"\n      },\n      \"timestamp\" => \"2017-01-21 12:51:34\",\n      \"type\" => \"relation\",\n      \"visible\" => true\n    }\n\nWith parameterized query:\n\n    iex> opts = [\n    ...>   access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n    ...>   secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n    ...>   region: System.fetch_env!(\"AWS_REGION\"),\n    ...>   database: \"default\",\n    ...>   output_location: System.fetch_env!(\"AWS_ATHENA_OUTPUT_LOCATION\")\n    ...> ]\n    iex> query = \"SELECT id, type FROM planet WHERE id = ? and type = ?\"\n    iex> req = Req.new() |> ReqAthena.attach(opts)\n    iex> Req.post!(req, athena: {query, [239_970_142, \"node\"]}, format: :json).body\n    [%{\"id\" => 239970142, \"type\" => \"node\"}]","ref":"ReqAthena.html#attach/2-examples"},{"type":"extras","title":"ReqAthena","doc":"# ReqAthena\n\n[![Docs](https://img.shields.io/badge/hex.pm-docs-8e7ce6.svg)](https://hexdocs.pm/req_athena)\n[![Hex pm](http://img.shields.io/hexpm/v/req_athena.svg?style=flat&color=blue)](https://hex.pm/packages/req_athena)\n\n[Req](https://github.com/wojtekmach/req) plugin for [AWS Athena](https://docs.aws.amazon.com/athena/latest/APIReference/Welcome.html).\n\nReqAthena makes it easy to make Athena queries. Query results are decoded into the `ReqAthena.Result` struct.\nThe struct implements the `Table.Reader` protocol and thus can be efficiently traversed by rows or columns.","ref":"readme.html"},{"type":"extras","title":"Usage - ReqAthena","doc":"```elixir\nMix.install([\n  {:req, \"~> 0.3.5\"},\n  {:req_athena, \"~> 0.1.3\"}\n])\n\nopts = [\n  access_key_id: System.fetch_env!(\"AWS_ACCESS_KEY_ID\"),\n  secret_access_key: System.fetch_env!(\"AWS_SECRET_ACCESS_KEY\"),\n  region: System.fetch_env!(\"AWS_REGION\"),\n  database: \"default\",\n  output_location: \"s3://my-bucket\"\n]\n\nreq = Req.new() |> ReqAthena.attach(opts)\n\n# Create table from Registry of Open Data on AWS\n# See: https://registry.opendata.aws/osm/\nquery = \"\"\"\nCREATE EXTERNAL TABLE IF NOT EXISTS planet (\n  id BIGINT,\n  type STRING,\n  tags MAP ,\n  lat DECIMAL(9,7),\n  lon DECIMAL(10,7),\n  nds ARRAY >,\n  members ARRAY >,\n  changeset BIGINT,\n  timestamp TIMESTAMP,\n  uid BIGINT,\n  user STRING,\n  version BIGINT,\n  visible BOOLEAN\n)\nSTORED AS ORCFILE\nLOCATION 's3://osm-pds/planet/';\n\"\"\"\n\nReq.post!(req, athena: query).body\n# =>\n# %{\n#   \"Output\" => \"\",\n#   \"ResultSet\" => %{\n#     \"ColumnInfos\" => [],\n#     \"ResultRows\" => [],\n#     \"ResultSetMetadata\" => %{\"ColumnInfo\" => []},\n#     \"Rows\" => []\n#   }\n# }\n\n# With plain string query\nquery = \"SELECT id, type, tags, members, timestamp, visible FROM planet WHERE id = 470454 and type = 'relation'\"\n\nReq.post!(req, athena: query, format: :json).body\n# =>\n# [\n#  %{\n#    \"id\" => 470454,\n#    \"members\" => [\n#      %{\"ref\" => 670007839, \"role\" => \"\", \"type\" => \"node\"},\n#      %{\"ref\" => 670007840, \"role\" => \"\", \"type\" => \"node\"}\n#    ],\n#    \"tags\" => %{\n#      \"name\" => \"Mérignac A\",\n#      \"network\" => \"NTF-5\",\n#      \"ref\" => \"17229A\",\n#      \"site\" => \"geodesic\",\n#      \"source\" => \"©IGN 2010 dans le cadre de la cartographie réglementaire\",\n#      \"type\" => \"site\",\n#      \"url\" => \"http://geodesie.ign.fr/fiches/index.php?module=e&action=fichepdf&source=carte&sit_no=17229A\"\n#    },\n#    \"timestamp\" => \"2017-01-21 12:51:34\",\n#    \"type\" => \"relation\",\n#    \"visible\" => true\n#  }\n# ]\n\n# With parameterized query\nquery = \"SELECT id, type FROM planet WHERE id = ? and type = ?\"\n\nReq.post!(req, athena: {query, [239_970_142, \"node\"]}).body\n#=> [%{\"id\" => 239970142, \"type\" => \"node\"}]\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - ReqAthena","doc":"Copyright (C) 2022 Dashbit\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}